// ----------------------------------------------------------------------------
//
//  Copyright (C) 2017 Fons Adriaensen <fons@linuxaudio.org>
//    
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// ----------------------------------------------------------------------------


#ifndef __ABCONFIG_H
#define __ABCONFIG_H


// Configuration data for octoproc and octofile.
// The file format is binary OSC.


class ABconfig
{
public:

    ABconfig (void);

    void reset (void);
    int  save (const char *file);  // Save data to file.
    int  load (const char *file);  // Read data to file.
    int  dump (const char *file);  // Dump to stdout.
    
    // Convolution data files will exist for sampler rates
    // 44.1, 48 and 96 kHz. They should be stored in the
    // same directory as the configuration file referring
    // to them.

    // Returns the full path of the convolution data file.
    // The string can be deallocated using free() after use.
    const char *convolfilepath (int fsamp);

    int       _version;            // Configuration format version.
    
    char      _origin [64];        // Creator (program or persion) of this file.
    char      _descript [64];      // Description of how the data was generated.
    char      _micident [64];      // Type and serial number of microphone. 
    char      _convfile [64];      // Base name of the convolution data file.

    float     _lfeq1_f;            // Low frequency E, center frequency (Hz).
    float     _lfeq1_g;            // Gain (dB).
    float     _lfeq1_b;            // Relative bandwidth.

    
private:

    void setdirname (const char *file);
    
    char     *_dirname;
    
};


#endif
