// ----------------------------------------------------------------------------
//
//  Copyright (C) 2007-2017 Fons Adriaensen <fons@linuxaudio.org>
//    
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// ----------------------------------------------------------------------------


#include <math.h>
#include "svparf.h"


static const float FPI = M_PI;
static const float EPS = 1e-20f;



void Svpar_conf::setpars (float f, float g, float b)
{
    float w, c1, c2, d1, d2;

    w = tanf (FPI * f);
    if (g < 1.0f) b /= g;
    g -= 1;
    c1 = w * b;
    c2 = w * w;
    d1 = 1 + c1 + c2;
    d2 = c1 + 2 * c2;
    _b1 = 2 * d2 / d1;
    _b2 = 2 * c2 / d2;
    _a1 = g * (1 - _b2);
    _a0 = _a1 * d2 / d1;
}



void Svpar_filt::process (const Svpar_conf *C, int n, float *ip, float *op)
{
    float x, y, z1, z2;

    z1 = _z1;
    z2 = _z2;
    while (n--)
    {
	x = *ip++;
        y = x - z1 - z2 + EPS;
        *op++ = x + C->_a0 * y + C->_a1 * z1;
        z2 += C->_b2 * z1;
        z1 += C->_b1 * y;
    }
    _z1 = z1;
    _z2 = z2;
}
